@@ -1,5 +1,5 @@
 /* copy.c -- core functions for copying files and directories
-   Copyright (C) 89, 90, 91, 1995-2003 Free Software Foundation.
+   Copyright (C) 89, 90, 91, 1995-2004 Free Software Foundation.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,19 +27,18 @@
 #endif
 
 #include "system.h"
-#include "error.h"
 #include "backupfile.h"
-#include "savedir.h"
 #include "copy.h"
 #include "cp-hash.h"
+#include "dirname.h"
+#include "error.h"
+#include "full-write.h"
 #include "hash.h"
 #include "hash-pjw.h"
-#include "same.h"
-#include "dirname.h"
-#include "full-write.h"
 #include "path-concat.h"
 #include "quote.h"
 #include "same.h"
+#include "savedir.h"
 #include "utimens.h"
 #include "xreadlink.h"
 
@@ -311,7 +310,7 @@ copy_reg (const char *src_path, const char *dst_path,
 
   /* Make a buffer with space for a sentinel at the end.  */
 
-  buf = (char *) alloca (buf_size + sizeof (int));
+  buf = alloca (buf_size + sizeof (int));
 
   for (;;)
     {
@@ -640,8 +639,8 @@ overwrite_prompt (char const *dst_path, struct stat const *dst_sb)
 }
 
 /* Hash an F_triple.  */
-static unsigned int
-triple_hash (void const *x, unsigned int table_size)
+static size_t
+triple_hash (void const *x, size_t table_size)
 {
   struct F_triple const *p = x;
 
@@ -653,15 +652,15 @@ triple_hash (void const *x, unsigned int table_size)
      to be very large to make the N^2 factor noticable, and
      one would probably encounter a limit on the length of
      a command line before it became a problem.  */
-  unsigned int tmp = hash_pjw (p->name, table_size);
+  size_t tmp = hash_pjw (p->name, table_size);
 
   /* Ignoring the device number here should be fine.  */
   return (tmp | p->st_ino) % table_size;
 }
 
 /* Hash an F_triple.  */
-static unsigned int
-triple_hash_no_name (void const *x, unsigned int table_size)
+static size_t
+triple_hash_no_name (void const *x, size_t table_size)
 {
   struct F_triple const *p = x;
 
@@ -1037,8 +1036,11 @@ copy_internal (const char *src_path, const char *dst_path,
 		  return 1;
 		}
 
-	      dst_backup = (char *) alloca (strlen (tmp_backup) + 1);
-	      strcpy (dst_backup, tmp_backup);
+	      /* Using alloca for a pathname that may be (in theory) arbitrarily
+		 long is not recommended.  In fact, even forming such a name
+		 should be discouraged.  Eventually, this code will be rewritten
+		 to use fts, so using alloca here will be less of a problem.  */
+	      ASSIGN_STRDUPA (dst_backup, tmp_backup);
 	      free (tmp_backup);
 	      if (rename (dst_path, dst_backup))
 		{
@@ -1307,7 +1309,7 @@ copy_internal (const char *src_path, const char *dst_path,
 
       /* Insert the current directory in the list of parents.  */
 
-      dir = (struct dir_list *) alloca (sizeof (struct dir_list));
+      dir = alloca (sizeof *dir);
       dir->parent = ancestors;
       dir->ino = src_sb.st_ino;
       dir->dev = src_sb.st_dev;
@@ -1401,10 +1403,7 @@ copy_internal (const char *src_path, const char *dst_path,
     }
   else if (S_ISREG (src_type)
 	   || (x->copy_as_regular && !S_ISDIR (src_type)
-#ifdef S_ISLNK
-	       && !S_ISLNK (src_type)
-#endif
-	       ))
+	       && !S_ISLNK (src_type)))
     {
       copied_as_regular = 1;
       /* POSIX says the permission bits of the source file must be
@@ -1427,10 +1426,7 @@ copy_internal (const char *src_path, const char *dst_path,
   else
 #endif
     if (S_ISBLK (src_type) || S_ISCHR (src_type)
-#ifdef S_ISSOCK
-	|| S_ISSOCK (src_type)
-#endif
-	)
+	|| S_ISSOCK (src_type))
     {
       if (mknod (dst_path, get_dest_mode (x, src_mode), src_sb.st_rdev))
 	{
@@ -1460,7 +1456,7 @@ copy_internal (const char *src_path, const char *dst_path,
 	    {
 	      /* See if the destination is already the desired symlink.  */
 	      size_t src_link_len = strlen (src_link_val);
-	      char *dest_link_val = (char *) alloca (src_link_len + 1);
+	      char *dest_link_val = alloca (src_link_len + 1);
 	      int dest_link_len = readlink (dst_path, dest_link_val,
 					    src_link_len + 1);
 	      if ((size_t) dest_link_len == src_link_len
